"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const TokenType_1 = require("./TokenType");
class Token {
    /**
     * @constructor
     * @param {TokenType} type The type of the token
     * @param {*} value The value of the token
     * @param {number} line The line where the token is located in the source
     * @param {number} column The column where the token is located in the source
     */
    constructor(type, value, line, column) {
        this.type = type;
        this.value = value;
        this.line = line;
        this.column = column;
    }
    /**
     * Tests the current token for a type and/or a content.
     *
     * @param {TokenType} type
     * @param {string|string[]|number} values
     * @returns {boolean}
     */
    test(type, values = null) {
        return (this.type === type) && (values === null || (Array.isArray(values) && values.includes(this.value)) || this.value == values);
    }
    /**
     * Return the line where the token is located in the source.
     *
     * @return {number}
     */
    getLine() {
        return this.line;
    }
    /**
     * Return the column where the token is located in the source.
     *
     * @return {number}
     */
    getColumn() {
        return this.column;
    }
    /**
     * Return the type of the token.
     *
     * @return {TokenType}
     */
    getType() {
        return this.type;
    }
    /**
     * Return the value of the token.
     *
     * @return {*}
     */
    getValue() {
        return this.value;
    }
    /**
     * Return the human-readable representation of the token.
     *
     * @return {string}
     */
    toString() {
        return `${TokenType_1.typeToString(this.type, true)}(${this.value ? this.value : ''})`;
    }
    /**
     * Serialize the token to a Twig source.
     *
     * @return {string}
     */
    serialize() {
        return this.value;
    }
}
exports.Token = Token;
